@@ -1,5 +1,5 @@
 """Victor Smart Kill API module."""
 # flake8: noqa: F401
 from ._api import VictorApi
-from ._client import InvalidCredentialsError, VictorAsyncClient
+from ._client import VictorAsyncClient
 from ._models import Activity, MobileApp, Operator, Profile, Trap, User
