@@ -8,10 +8,6 @@ log = logging.getLogger(__name__)
 DEFAULT_BASE_URL = URL("https://www.victorsmartkill.com")
 
 
-class InvalidCredentialsError(Exception):
-    """Invalid authentication credentials."""
-
-
 class VictorAsyncClient(AsyncClient):
     """An asynchronous HTTP client to Victor Smart Kill API."""
 
@@ -52,11 +48,6 @@ class VictorAsyncClient(AsyncClient):
             json=self._credentials,
         )
 
-        if response.status_code == codes.BAD_REQUEST:
-            if response.content.find(b"credentials") != -1:
-                log.debug("Credentials error: %s", str(response.content))
-                raise InvalidCredentialsError(response.content)
-
         response.raise_for_status()
 
         token = response.json().get("token")
@@ -83,17 +74,16 @@ class VictorAsyncClient(AsyncClient):
             await self.fetch_token()
 
         if not headers:
-            request_headers = {}
+            request_headers = dict()
         else:
             request_headers = headers.copy()
 
         request_headers["Authorization"] = f"Token {self._token}"
 
-        if log.isEnabledFor(logging.DEBUG):
-            log.debug("Adding token to request.")
-            log.debug("Requesting url %s using method %s.", url, method)
-            log.debug("Supplying headers %s and data %s.", request_headers.keys(), data)
-            log.debug("Passing through key word arguments %s.", kwargs)
+        log.debug("Adding token to request.")
+        log.debug("Requesting url %s using method %s.", url, method)
+        log.debug("Supplying headers %s and data %s.", request_headers.keys(), data)
+        log.debug("Passing through key word arguments %s.", kwargs)
 
         response = await super().request(
             method, url, headers=request_headers, data=data, **kwargs
@@ -106,13 +96,4 @@ class VictorAsyncClient(AsyncClient):
                 False, method, url, data=data, headers=headers, **kwargs
             )
 
-        if log.isEnabledFor(logging.DEBUG):
-            log.debug(
-                "Response status code %d from %s %s with content: %s",
-                response.status_code,
-                method,
-                url,
-                response.content,
-            )
-
         return response
